==> haskell-citeproc-0.8.1.1-76-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1.1
visibility:           public
id:                   citeproc-0.8.1.1-HiFo28yG2GL22Ajj97jiCf
key:                  citeproc-0.8.1.1-HiFo28yG2GL22Ajj97jiCf
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  5ec771bee21328e8d10e6415bb1440a2
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1.1-HiFo28yG2GL22Ajj97jiCf
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    pandoc-types-1.23.1-84C04huNeQE19kRVi0p0kr
    safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2
    text-icu-0.8.0.5-A9FVi08iiEp7aZs1bD0PGz transformers-0.6.1.0
    unicode-collation-0.1.3.6-JSBcmSrCkYr8kT1XHjvyN0
    uniplate-1.6.13-3WatGBC3kLsu5Mf9WJ1JN
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    xml-conduit-1.9.1.4-4ApAZ67Z6lCGy52B3tehMj

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-citeproc-0.8.1.1-77-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1.1
visibility:           public
id:                   citeproc-0.8.1.1-IJ1hyj1afcS8qf2U9MmGm2
key:                  citeproc-0.8.1.1-IJ1hyj1afcS8qf2U9MmGm2
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  26e25c8ca8f3c7b5893e4ee0ac49afd2
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1.1-IJ1hyj1afcS8qf2U9MmGm2
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    pandoc-types-1.23.1-8LyhSCLdqfo18RNKTPAafp
    safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    text-icu-0.8.0.5-5tHL6P8peeE4Pci3Zs7Ly9 transformers-0.6.1.0
    unicode-collation-0.1.3.6-Dz3eyIYZt3d6TCHR91D3u8
    uniplate-1.6.13-KGH5CSn0bIt6TRjVfDPPFU
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    xml-conduit-1.9.1.4-AWUHrHEyod1C1UJeqVfDQt

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
